Rebuild the constraint matrix from a recipe
Arguments
- recipe
The covariate expansion recipe stored on a balancing result.
- .data
The data frame the recipe was built from.
Rebuild the constraint matrix from a recipe
The covariate expansion recipe stored on a balancing result.
The data frame the recipe was built from.